/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.task;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.model.AbstractEntityManager;
import nl.cloudfarming.client.model.AgroURI;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public abstract class TaskManager<T extends Task> extends AbstractEntityManager<T> {

    private static final Logger LOGGER = Logger.getLogger(TaskManager.class.getCanonicalName());
    private PropertyChangeSupport support = new PropertyChangeSupport(this);
    public static final String PROP_TASK_ADDED = "taskAdded";
    public static final String TASKS_DIR_NAME = "Tasks";

    public FileObject getTaskDirectory(Project project) {
        FileObject projectDirectory = project.getProjectDirectory();
        FileObject tasksDirectory = projectDirectory.getFileObject(TASKS_DIR_NAME);
        if (tasksDirectory == null) {
            try {
                tasksDirectory = projectDirectory.createFolder(TASKS_DIR_NAME);
            } catch (IOException ex) {
                LOGGER.log(Level.WARNING, "Unable to create Task directory {0}", ex.getMessage());
            }
        }
        return tasksDirectory;
    }

    public abstract FileObject getStorageFolder(Project project);

    public void addPropertyChangeListener(PropertyChangeListener listener, String propertyName) {
        getPropertyChangeSupport().addPropertyChangeListener(propertyName, listener);
    }

    public void removePropertyChangeListener(PropertyChangeListener listener, String propertyName) {
        getPropertyChangeSupport().removePropertyChangeListener(propertyName, listener);
    }

    public PropertyChangeSupport getPropertyChangeSupport() {
        return support;
    }

    public static Project findProject(AgroURI agroURI) {
        return EnterpriseIdProvider.ProjectFinder.find(agroURI);
    }
}
