/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.task.factory;

import java.util.List;
import javax.swing.*;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle.Messages;

/**
 * Actual panel, part of the wizard to select a TaskObjectFactory, containing a combobox containing all specified factories.
 * @author Gerben Feenstra
 */
@Messages({
    "TaskObjectFactorySelectPanel_selectionlist_prompt=Source:"
})
public class TaskObjectFactorySelectPanel extends JPanel {

    private static final String SELECTION_LIST_PROMPT = Bundle.TaskObjectFactorySelectPanel_selectionlist_prompt();
    
    private ComboBoxModel<TaskObjectFactory> comboBoxModel = new DefaultComboBoxModel<TaskObjectFactory>();
    private JComboBox factoryComboBox;
    private JLabel caption;
    private JLabel selectionListPrompt;

    public TaskObjectFactorySelectPanel(String panelText) {
        // Set layout
        this.setLayout(new MigLayout("wrap 2"));

        // Create combobox
        factoryComboBox = new JComboBox();
        factoryComboBox.setModel(comboBoxModel);

        // Create caption Text
        caption = new JLabel(panelText);
        selectionListPrompt = new JLabel(SELECTION_LIST_PROMPT);
        this.add(caption, "span");
        this.add(selectionListPrompt);
        this.add(factoryComboBox);
    }

    public ComboBoxModel<TaskObjectFactory> getComboBoxModel() {
        return comboBoxModel;
    }

    public void setTaskObjectFactories(List<TaskObjectFactory> factories){
        for(TaskObjectFactory factory : factories){
            factoryComboBox.addItem(factory);
        }
    }
}
